skillset

# XMLRésuméLibrary: User Guide

skills | Element Reference | state

## Name

skillset — A titled group of one or more related skills

## Synopsis

### Content Model

    (title?,(skill+|skills))

### Attributes

Name | Type | Default
--- | --- | ---
id | ID | None
targets | CDATA | None

## Description

The `skillset` element contains a titled set of (usually closely) related skills.

### Formatting

The `skills.format` parameter controls the formatting of skill sets.

### Parents

`skillset` may be contained in these elements: `skillarea`

### Attributes

`id`

  A string used to uniquely identify a skill set. The skill set may then be referred to by this identifier.

## Examples

    <skillset>
      <title>Eating Utinsels</title>
      <skill>Knife</skill>
      <skill>Fork</skill>
      <skill>Spoon</skill>
      <skill>Soup Spoon</skill>
    </skillset>

skills | Element Reference | state